@@ -82,17 +82,16 @@ def makeA(data_ord):
     print("Tinv")
     di =  sparse.coo_matrix((np.sqrt(1/np.array(dii_c)), (np.array(range(N)), np.array(range(N)))), shape=(N,N), dtype=np.float64).tocsr()
     #X = Tinv.dot(di).tocsc() ##upper
-    X = sparse.csr_matrix(Tinv.dot(di),dtype=np.float32)
+    X = sparse.csr_matrix(Tinv.dot(di),dtype=np.float64)
     print("X")
-    Ip = sparse.identity(N,dtype='float32', format='dia').toarray() ## 最快的方法 7.7秒3W int8
+    Ip = sparse.identity(N,dtype='float64', format='dia').toarray() ## 最快的方法 7.7秒3W int8
     print("ip")
     tu = spsolve_triangular(X,Ip,False,overwrite_A=True, overwrite_b=True)
-    #tu = sparse.csr_matrix(tu,dtype=np.float32)
+    tu = sparse.csr_matrix(tu,dtype=np.float64)
     print("tu")
     del Ip, X
     gc.collect()
     #tu = spsolve_triangular(X,Ip,False)
     #tu = sparse.linalg.inv(X).tocsr()
-    #A = tu.T.dot(tu)
-    A = np.einsum('ij,jk->ik',tu.T,tu)
-    return [A, data_ord.iloc[:,0]]
\ No newline at end of file
+    A = tu.T.dot(tu)
+    return [A.astype(np.float32), data_ord.iloc[:,0]]
\ No newline at end of file
